job "navidrome" {


  datacenters = ["dc1"]
  region      = "global"


  group "navidrome" {
    shutdown_delay = "6s"



    ephemeral_disk {
      # Use minimal ephemeral disk
      size = 101
    }


    network {
      mode = "bridge"
    }



    volume "data" {
      source          = "navidrome-data"
      type            = "csi"
      access_mode     = "single-node-writer"
      attachment_mode = "file-system"
    }

    volume "music" {
      source          = "music"
      type            = "csi"
      read_only       = true
      access_mode     = "multi-node-reader-only"
      attachment_mode = "file-system"
    }


    service {
      name = "navidrome"
      port = 4533

      meta {
        alloc      = "${NOMAD_ALLOC_INDEX}"
        datacenter = "${NOMAD_DC}"
        group      = "${NOMAD_GROUP_NAME}"
        job        = "${NOMAD_JOB_NAME}"
        namespace  = "${NOMAD_NAMESPACE}"
        node       = "${node.unique.name}"
        region     = "${NOMAD_REGION}"
      }

      connect {
        sidecar_service {
        }
        sidecar_task {
          config {
            args = [
              "-c",
              "${NOMAD_SECRETS_DIR}/envoy_bootstrap.json",
              "-l",
              "${meta.connect.log_level}",
              "--concurrency",
              "${meta.connect.proxy_concurrency}",
              "--disable-hot-restart"
            ]
          }

          resources {
            cpu    = 50
            memory = 64
          }

        }
      }


      check {
        name     = "health"
        type     = "http"
        path     = "/ping"
        expose   = true
        interval = "30s"
        timeout  = "5s"

        check_restart {
          limit = 20
          grace = "20s"
        }
      }

      # The music volume can be unavailable for several reason.
      # One of them is if it's on a fuse volume and it starts getting "transport unavailable" errors
      # In this case, the alloc should be restarted
      check {
        name     = "music"
        type     = "script"
        interval = "120s"
        timeout  = "7s"
        task     = "navidrome"
        command  = "sh"
        args = [
          "-c",
          "ls /music/ > /dev/null"
        ]
        check_restart {
          limit = 5
          grace = "30s"
        }
      }

      tags = [

        "traefik.enable=true",
        "traefik.http.routers.navidrome.entrypoints=https",
        "traefik.http.routers.navidrome.rule=Host(`navidrome.domain.tld`)",
        "traefik.http.middlewares.csp-navidrome.headers.contentsecuritypolicy=default-src 'self';font-src 'self' data:;img-src 'self' data:;script-src 'self' 'unsafe-inline' 'unsafe-eval';style-src 'self' 'unsafe-inline';",
        "traefik.http.middlewares.navidrome-redir.redirectregex.regex=^(https://[^/]+)/?$",
        "traefik.http.middlewares.navidrome-redir.redirectregex.replacement=/app/",
        "traefik.http.routers.navidrome.middlewares=security-headers@file,navidrome-redir,rate-limit-std@file,forward-proto@file,inflight-std@file,hsts@file,compression@file,csp-navidrome",

      ]
    }





    task "navidrome" {
      driver = "docker"
      user   = 4533

      config {
        image           = "deluan/navidrome:0.52.0"
        readonly_rootfs = true

        pids_limit = 100
      }

      env {
        ND_MUSICFOLDER           = "/music"
        ND_DATAFOLDER            = "/data"
        ND_BASEURL               = ""
        ND_ADDRESS               = "127.0.0.1"
        ND_REVERSEPROXYWHITELIST = "127.0.0.0/8"
      }



      # Use a template block instead of env {} so we can fetch values from vault
      template {
        data        = <<_EOT
LANG=fr_FR.utf8
ND_ENABLEGRAVATAR=false
ND_ENABLESHARING=true
ND_ENABLETRANSCODINGCONFIG=true
TZ=Europe/Paris
_EOT
        destination = "secrets/.env"
        perms       = 400
        env         = true
      }


      volume_mount {
        volume      = "music"
        destination = "/music"
        read_only   = true
      }

      volume_mount {
        volume      = "data"
        destination = "/data"
      }


      resources {
        cpu        = 200
        memory     = 256
        memory_max = 512
      }

    }
  }
}

# vim: syntax=hcl
